@@ -1,26 +1,17 @@
-# $Author: ddumont $
-# $Date: 2009-09-27 16:02:38 +0200 (dim 27 sep 2009) $
-# $Revision: 1036 $
-
-#    Copyright (c) 2009 Dominique Dumont.
 #
-#    This file is part of Config-Model-Approx.
+# This file is part of Config-Model-Approx
 #
-#    Config-Model-Approx is free software; you can redistribute it and/or
-#    modify it under the terms of the GNU Lesser Public License as
-#    published by the Free Software Foundation; either version 2.1 of
-#    the License, or (at your option) any later version.
+# This software is Copyright (c) 2012 by Dominique Dumont.
 #
-#    Config-Model-Approx is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-#    Lesser Public License for more details.
+# This is free software, licensed under:
+#
+#   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-#    You should have received a copy of the GNU Lesser Public License
-#    along with Config-Model; if not, write to the Free Software
-#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 
 package Config::Model::Approx ;
+{
+  $Config::Model::Approx::VERSION = '1.005';
+}
 
 use strict ;
 use warnings ;
@@ -30,10 +21,6 @@ use Log::Log4perl;
 use File::Copy ;
 use File::Path ;
 
-use vars qw($VERSION)  ;
-
-$VERSION = '1.002' ;
-
 my $logger = Log::Log4perl::get_logger(__PACKAGE__);
 
 sub read {
@@ -42,12 +29,16 @@ sub read {
 
     $logger->info("loading config file $args{file}") if defined $args{file};
 
+    die "Cannot read $args{config_dir}$args{file}\n" unless defined $args{io_handle} ;
+
     foreach ($args{io_handle}->getlines) {
 	chomp;
 	s/#.*//;
 	s/\s+/=/; # translate file in string loadable by C::M::Loader
 	next unless $_;
-	my $load = s/^\$// ? $_ : "distributions:".$_;
+	my $load = s/^\$// ? $_ 
+                 : m!://!  ? "distributions:".$_
+                 :           $_ ; # old style parameter
 	$args{object}->load($load) ;
     }
 
@@ -63,7 +54,7 @@ sub write {
 
     $ioh->print("# This file was written by Config::Model with Approx model\n");
     $ioh->print("# You may modify the content of this file. Configuration \n");
-    $ioh->print("# modification will be preserved. Modification in the comments\n");
+    $ioh->print("# modifications will be preserved. Modifications in the comments\n");
     $ioh->print("# will be discarded\n\n");
 
     # Using Config::Model::ObjTreeScanner would be overkill
@@ -84,7 +75,7 @@ sub write {
 
     my $h = $node->fetch_element('distributions') ;
     $ioh->print("# ", $node->get_help(summary => 'distributions'),"\n");
-    foreach my $dname ($h->get_all_indexes) {
+    foreach my $dname ($h->fetch_all_indexes) {
 	$ioh->printf("%-10s %s\n",$dname,
 		     $node->grab_value("distributions:$dname")
 		    ) ;
@@ -101,28 +92,33 @@ Config::Model::Approx - Approx configuration file editor
 
 =head1 SYNOPSIS
 
+ # full blown editor
+ sudo cme edit approx
+ 
+ # command line use
+ sudo cme modify approx distributions:multimedia=http://www.debian-multimedia.org
+
  use Config::Model ;
  my $model = Config::Model -> new ( ) ;
 
  my $inst = $model->instance (root_class_name   => 'Approx');
  my $root = $inst -> config_root ;
 
- $root->load("distribution:multimedia=http://www.debian-multimedia.org") ;
+ $root->load("distributions:multimedia=http://www.debian-multimedia.org") ;
 
  $inst->write_back() ;
 
 =head1 DESCRIPTION
 
-This module provides a configuration model for Approx. Then
-Config::Model provides a graphical editor program for
-F</etc/approx/approx.conf>. See L<config-edit-approx> more help.
-
-This module and Config::Model can also be used from Perl programs to
-modify safely the content of F</etc/approx/approx.conf>.
+This module provides a configuration editor for Approx. Running L<cme> as root
+will update C</etc/approx/approc.conf>.
 
 Once this module is installed, you can run:
 
- # config-edit-approx
+ # cme edit approx
+
+This module and Config::Model can also be used from Perl programs to
+modify safely the content of F</etc/approx/approx.conf>.
 
 The Perl API is documented in L<Config::Model> and mostly in
 L<Config::Model::Node>.
@@ -148,7 +144,7 @@ Dominique Dumont, (ddumont at cpan dot org)
 
 =head1 LICENSE
 
-   Copyright (c) 2009 Dominique Dumont.
+   Copyright (c) 2009,2012 Dominique Dumont.
 
    This file is part of Config-Model-Approx.
 
